==> haskell-resource-pool-0.2.3.2-59-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-9mPVOmvtSdv8pD583sEGFn
key: resource-pool-0.2.3.2-9mPVOmvtSdv8pD583sEGFn
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
abi: 280ec94454695eb9e3e6fd1a657944f8
exposed: True
exposed-modules:
    Data.Pool
import-dirs: /usr/lib/ghc-8.6.4/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-9mPVOmvtSdv8pD583sEGFn
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    monad-control-1.0.2.3-3fyG0gh4gjL4D9yi94eZx stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-LOZfHxBYQIt6vOmm2orzyE
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-1JJjPWf2sjY1SqYiWQYEpD
key: resource-pool-0.2.3.2-1JJjPWf2sjY1SqYiWQYEpD
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
abi: 38f82445912da47163a08dfc60e06aaf
exposed: True
exposed-modules:
    Data.Pool
import-dirs: /usr/lib/ghc-8.6.4/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-1JJjPWf2sjY1SqYiWQYEpD
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    monad-control-1.0.2.3-CbJ0M7iQh3tCaJfGqTvvKL stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-AYmaSZMrRmtI5aj5cOhHJQ
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
